@@ -6,5 +6,5 @@ var searchData=
   ['license_20許可協議_3',['License 許可協議',['../index.html#autotoc_md25',1,'']]],
   ['line_4',['Command Line',['../index.html#autotoc_md12',1,'']]],
   ['links_20相關鏈接_5',['Links 相關鏈接',['../index.html#autotoc_md28',1,'']]],
-  ['linux_20mac_20os_20x_6',['linux mac os x',['../index.html#autotoc_md18',1,'Linux &amp; Mac OS X'],['../index.html#autotoc_md21',1,'Linux &amp; Mac OS X']]]
+  ['linux_20mac_20os_20x_6',['Linux Mac OS X',['../index.html#autotoc_md18',1,'Linux &amp; Mac OS X'],['../index.html#autotoc_md21',1,'Linux &amp; Mac OS X']]]
 ];
